@@ -11,9 +11,13 @@ class ProcessorService(processor_pb2_grpc.ProcessorServicer):
     def Execute(self, request, context):
         # get the string from the incoming request
         flow_name = request.flowName
-        json_string = request.jsonString
+        data = request.data
 
-        for item in self.flow_manager.run(flow_name, json.loads(json_string)):
+        try:
+            data = json.loads(data)
+        except:
+            pass
+        for item in self.flow_manager.run(flow_name, data):
             yield processor_pb2.FlowResponse(
                 jsonString=json.dumps(item), streamEnd=False
             )
